@@ -9,6 +9,8 @@ from typing import Any, Iterable, Union
 
 from referencing import Anchor, Registry, Resource, Specification, exceptions
 from referencing._attrs import frozen
+from referencing._core import _UNSET  # type: ignore[reportPrivateUsage]
+from referencing._core import _Unset  # type: ignore[reportPrivateUsage]
 from referencing._core import Resolved as _Resolved, Resolver as _Resolver
 from referencing.typing import URI, Anchor as AnchorType, Mapping
 
@@ -334,9 +336,10 @@ def _maybe_in_subresource_crazy_items_dependencies(
     ) -> _Resolver[Any]:
         _segments = iter(segments)
         for segment in _segments:
-            if (
-                segment == "items" or segment == "dependencies"
-            ) and isinstance(subresource.contents, Mapping):
+            if segment in {"items", "dependencies"} and isinstance(
+                subresource.contents,
+                Mapping,
+            ):
                 return resolver.in_subresource(subresource)
             if segment not in in_value and (
                 segment not in in_child or next(_segments, None) is None
@@ -559,7 +562,7 @@ _SPECIFICATIONS: Registry[Specification[Schema]] = Registry(
 
 def specification_with(
     dialect_id: URI,
-    default: Specification[Any] = None,  # type: ignore[reportGeneralTypeIssues]
+    default: Specification[Any] | _Unset = _UNSET,
 ) -> Specification[Any]:
     """
     Retrieve the `Specification` with the given dialect identifier.
@@ -573,7 +576,7 @@ def specification_with(
     resource = _SPECIFICATIONS.get(dialect_id.rstrip("#"))
     if resource is not None:
         return resource.contents
-    if default is None:  # type: ignore[reportUnnecessaryComparison]
+    if default is _UNSET:
         raise UnknownDialect(dialect_id)
     return default
 
